Carrying out a risk assessment with OiRA | OiRA

Topics

# Carrying out a risk assessment with OiRA

## Starting a new session

To start a new risk assessment click the link “Start a new session”.

## Opening a risk assessment

Once you’ve started a risk assessment, you can retrieve it any time through the dashboard under the header “My risk assessments”. This is the same place from which you can start a new risk assessment.

The dashboard.

## Navigating a risk assessment

Every risk assessment guides you through several steps. They are visible in the main menu on the left side:

- Preparation
- Involvement
- Assessment
- Action plan
- Report
- Status

Depending on decisions taken by the OiRA partners/tool developers, the architecture of the specific tool can vary. In some tools, the risk identification and evaluation phase also directly includes the action plan. In this case the left hand menu contains the following points:

- Preparation
- Involvement
- Assessment
- Report
- Status

## Preparation

Preparation is where you automatically start each session/tool. It is where you give the risk assessment a name that will help you later to distinguish several different risk assessments you have done with the tool.

The link “Learn more about this tool…” shows further information specifically on the selected tool and the parties involved in the development.

After clicking the button “Start”, some additional questions may be asked, depending on the tool you are using. This preparatory page with. “profile questions” only appears on tools that offer this option.

Here you can:

- Select or skip situation(s) relevant or not based on whether they apply to your business activity. Chose “Yes” where appropriate.
- List multiple business units, or branches, or stores, etc. The related risks will be repeated for each name you have entered.

The “Profile” screen in the Preparation step

The preparation step is very important as it accurately defines the type of business and the related risks your company deals with. After clicking “Save and continue” you will be automatically led to the next section “Involvement”.

Note: Many tools do not have profile questions, since they do not use this feature for targeting the tool. In that case, this screen is skipped automatically.

## Involvement

This step reminds you of the importance of worker involvement and offers different possibilities to ensure good worker involvement. Here you can download or print the contents of the risk assessment, for you to share it with your workers/employees. This assures that workers will be able to contribute to the task of assessing the situation at their workplace.

## Assessment

In this step you will identify hazards and problems in your company.

Note: Depending on how an OiRA tool was configured by the OiRA partner, the step “Action Plan” (see below) can already be integrated into this screen. In this case the whole step is called “Assessment”, and the elements described below under “Action Plan” will appear under the identification and evaluation of each risk.

Identification and Evaluation.

On the left of the page below “Identification + Evaluation”/ “Assessment” you can see all of the topics / modules included in the tool. The topic you are currently viewing is highlighted.

### Identification

For each single risk you have to decide if the described statement of a positive state is valid for your company:

- Yes: if you answer the positive statement in the headline with “yes”, no further action is needed, since you have assessed the risk as not being present.
- No: if you answer the statement with “no”, further action has to be taken. You will be asked to decide on specific measures.
- Not applicable: Some risk statements give you the possibility to select “not applicable” if the risk is not relevant for your company / establishment.

Normally there is more information on what a specific risk is about, listed below each statement that you need to answer:

- Information: a short description, optionally with illustrating images, provides more details about the risk.
- Resources: additional information about the risk, such as legal and policy references. Sometimes you can also find documents attached here for further reading.
- Comments: you can put your own comments here which will appear in your report at the end of the assessment.

After answering a risk statement and proceeding, the left hand menu will be updated with a coloured symbol, to indicate whether you have

- answered positively (green check)
- answered negatively (red cross)
- postponed (yellow question mark)
- for unanswered questions the grey symbol remains.

### Evaluation

In this step you evaluate the priority of a risk that you have identified.

Evaluating a risk.

Note: In some OiRA tools, the evaluation is not shown at all. This depends on how the respective partner has set up a particular OiRA tool.

If you have identified a risk as being present (red cross showing up), the section for evaluation will appear. Depending on the evaluation method set for each risk you will be asked to:

- directly estimate the priority: high, medium or low

Setting the priority of a risk.

OR

- answer three questions about the frequency, the severity and the probability of the risk, so that the priority can be calculated based on your answers.

Setting variables for a risk.

### Priority risks set by the sector:

Some risks are considered of high importance by the respective partner/tool developer who created the speciific OiRA tool. Such “priority risks” do not need to be estimated by you, since their priority will automatically be set to “high”.

Priority risks.

### Custom risks

After you have finished answering all risk topics under “Identification + Evaluation”/ “Assessment”, you arrive at the optional topic ”Other risks”. Here, the button “Add a custom risk” lets you create your own entries.

If you miss certain risks in the tool that are present at your workplace/in your company, you need to add custom risks at here. These risks can be completely defined/phrased by yourself.

Custom risks.

A “custom risk” works in very similar way to the risks provided by the OiRA tool, but obviously you need to write your own text: a short statement that describes a problematic situation (positive statement) and optionally a longer description. You can also upload an image for illustrating a certain situation.

As with the regular risks, you need to state whether the risk is present or not. This gives you the possibility to tick the custom risks off once you have dealt with them successfully but still keep them in your risk assessment for documentation purposes.

You can add as many custom risks as you need.

Add a custom risks.

## Action Plan

In this step you decide on the measures that you want to implement for eliminating or mitigating the risks that you have previously identified.

Note: As mentioned above, the action plan comes either as a separated step highlighted in the left hand menu or shows up under each identified risk. In the latter case the step in the left hand menu is called “Assessment” and includes both, the risk statements to answer and the solutions to chose.

It depends on decisions taken by the national OiRA partner/tool developer, which version you are provided with.

When the action plan is a separate step then it will be accessible through the left hand navigation.

### Integrated action plan

Integrated action plan.

If you answer a question with “No”, then the action plan module will unfold on the page.

You can both select from a list of measures proposed by the system and define your own measures.

### Seperate action plan

When the action plan is a separate step then it will be accessible through the left hand navigation.

Click the button “Create Action Plan” to start with your plan.

The main menu on the left now changes to show only the risks marked for further action, since the other subtopics will not be handled in the Action Plan.

For each risk answered with “No” during the evaluation process and for priority risks you will be asked to define measures.

The Action Plan.

You can both select from a list of measures proposed by the system and define your own measures.

#### Add your own measure

Needed Screenshot: action plan with smaller image to show measures on bottom

Use the button “Add measure” to start defining a preventive measure. Fill in the following information:

- Describe the general approach that will be taken to eliminate or reduce the risk.
- Optionally state the level of expertise and/or requirements needed (e.g. here you can add if specific training or external expertise is needed to deal with this risk)
- Enter information on who is responsible for the implementation.
- Define a budget, if applicable.
- Optionally set dates on when to start implementing the measure and by when you plan to have it finished.

You can add as many measures as needed.

#### Add standard measure

Depending on how the respective OiRA partner/tool developer has set up the OiRA tool, predefined measures are available for individual risks. To choose one or more predefined measures, click the button “Select standard measure”.

A popup menu opens that shows all proposed measures. Click the “Add”-Button behind the ones that you want to use. The predefined measures are then listed in your action plan. The description of what to do is fixed, but the other fields ( responsibility, budget, dates) can and should be filled by you.

Needed Screenshot: action plan with button add an extra measure clicked and form open

Both standard measures and measures defined by you can be deleted again at any point.

## Report

After finalising the Action Plan, you can retrieve a report.

If you want to leave a comment to be included in the report, type your text here and save it.

Comment the report.

See here to read more about the different reports and how to use them.

## Status

The small pie chart in the menu on the left shows you the general progress you already made in the tool.

The status section gives you an overview on how many risks you have identified, how many of them you have addressed already by deciding on measures and how many risks / statements you still haven’t answered.

The status page.

If you enter the status page, you can see how far you have progressed for each module. This can help you to note where you still need to assess risks or provide measures for those risks that you have identified.

Scroll to top
Back

## 3-carrying-out-a-risk-assessment.md

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search